package com.chelvc.cloud.vehicle.server.controller;

import com.chelvc.cloud.vehicle.client.constant.ExamineType;
import com.chelvc.cloud.vehicle.client.dto.DynamicContentDTO;
import com.chelvc.cloud.vehicle.client.param.AddDynamicContentParam;
import com.chelvc.cloud.vehicle.client.param.QueryAdminDynamicParam;
import com.chelvc.cloud.vehicle.client.param.QueryDynamicContentParam;
import com.chelvc.cloud.vehicle.server.service.DynamicContentService;
import com.chelvc.framework.common.model.Pagination;
import lombok.RequiredArgsConstructor;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.cloud.openfeign.SpringQueryMap;
import org.springframework.web.bind.annotation.*;

import java.util.Map;

/**
 * 动态信息Service接口
 *
 * @USER: igl
 * @date: 2023/8/8 15:13
 */
@RestController
@RequiredArgsConstructor(onConstructor = @__(@Autowired))
public class DynamicContentController {

    private final DynamicContentService dynamicContentService;

    /**
     * 查询动态信息
     */
    @GetMapping("/dynamicContent/queryById")
    public DynamicContentDTO queryById(@RequestParam("id") Long id, @RequestParam("userId") Long userId) {
        return dynamicContentService.queryById(id, userId);
    }

    /**
     * 查询动态信息列表
     */
    @GetMapping("/dynamicContent/queryPageList")
    public Pagination<DynamicContentDTO> queryPageList(@SpringQueryMap QueryDynamicContentParam param,
                                                       @RequestParam("pageNum") Integer pageNum,
                                                       @RequestParam("pageSize") Integer pageSize,
                                                       @RequestParam("userId") Long userId) {
        return dynamicContentService.queryPageList(param, pageNum, pageSize, userId);
    }

    /**
     * 查询动态信息列表
     */
    @GetMapping("/dynamicContent/queryAdminPageList")
    public Pagination<DynamicContentDTO> queryAdminPageList(QueryAdminDynamicParam param) {
        return dynamicContentService.queryAdminPageList(param);
    }

    /**
     * 查询动态信息列表
     */
    @GetMapping("/dynamicContent/queryUserById")
    public Pagination<DynamicContentDTO> queryUserById(@RequestParam("selfUserId") Long selfUserId,
                                                       @RequestParam("userId") Long userId,
                                                       @RequestParam("pageNum") Integer pageNum,
                                                       @RequestParam("pageSize") Integer pageSize) {
        return dynamicContentService.queryUserById(selfUserId, userId, pageNum, pageSize);
    }

    /**
     * 修改动态信息
     */
    @PostMapping("/dynamicContent/insertByBo")
    public void insertByBo(@RequestBody AddDynamicContentParam dto, @RequestParam("userId") Long userId) {
        dynamicContentService.insertByBo(dto, userId);
    }

    /**
     * 校验并批量删除动态信息信息
     */
    @DeleteMapping("/dynamicContent")
    public void deleteByIds(@RequestParam("id") Long id, @RequestParam("userId") Long userId) {
        dynamicContentService.deleteByIds(id, userId);
    }

    /**
     * 添加评论数
     *
     * @param dynamicId
     */
    @PostMapping("/dynamicContent/addComment")
    public Long addComment(@RequestParam("dynamicId") Long dynamicId) {
        return dynamicContentService.addComment(dynamicId);
    }

    /**
     * 减少评论数
     *
     * @param dynamicId
     */
    @PostMapping("/dynamicContent/reduceComment")
    public Long reduceComment(@RequestParam("dynamicId") Long dynamicId, @RequestParam("num") int num) {
        return dynamicContentService.reduceComment(dynamicId, num);
    }

    /**
     * 给评论添加点赞/踩
     *
     * @param dynamicStatus
     * @param contentId
     */
    @PostMapping("/dynamicContent/addNum")
    public Long addNum(@RequestParam("dynamicStatus") Integer dynamicStatus,
                       @RequestParam("contentId") Long contentId) {
        return dynamicContentService.addNum(dynamicStatus, contentId);
    }

    /**
     * 取消评论点赞/踩
     *
     * @param dynamicStatus
     * @param contentId
     */
    @PostMapping("/dynamicContent/reduceNum")
    public Long reduceNum(@RequestParam("dynamicStatus") Integer dynamicStatus,
                          @RequestParam("contentId") Long contentId) {
        return dynamicContentService.reduceNum(dynamicStatus, contentId);
    }

    /**
     * 屏蔽/恢复某条动态信息
     *
     * @param id 主键
     */
    @PostMapping("/dynamicContent/shieldById")
    public void shieldById(@RequestParam("id") Long id, @RequestParam("type") Integer type) {
        dynamicContentService.shieldById(id, type);
    }

    /**
     * 屏蔽/恢复某个用户所有动态信息
     *
     * @param userId 主键
     * @param type   状态 0-正常；1-平台屏蔽
     */
    @PostMapping("/dynamicContent/shieldByUserId")
    public void shieldByUserId(@RequestParam("userId") Long userId, @RequestParam("type") Integer type) {
        dynamicContentService.shieldByUserId(userId, type);
    }

    /**
     * 动态手动审核
     *
     * @param id
     * @param examine
     * @author igl
     * @date 2023/8/17 17:25
     */
    @PostMapping("/dynamicContent/examine")
    public void examine(@RequestParam("id") Long id, @RequestParam("examine") ExamineType examine) {
        dynamicContentService.examine(id, examine);
    }

    /**
     * 自动审核
     *
     * @param id             动态标识
     * @param platformStatus 平台状态
     * @param examineResult  审核结果
     * @author igl
     * @date 2023/9/12 17:25
     */
    @PostMapping("/dynamicContent/autoAudit")
    public void autoAudit(@RequestParam("id") Long id, @RequestParam("platformStatus") int platformStatus,
                          @RequestParam("examineResult") int examineResult) {
        dynamicContentService.autoAudit(id, platformStatus, examineResult);
    }

    /**
     * 视频审核回调
     *
     * @param param
     * @author igl
     * @date 2023/9/12 16:55
     */
    @PostMapping("/dynamicContent/videoAuditCallback")
    public void videoAuditCallback(@RequestBody Map<String, Object> param) {
        dynamicContentService.videoAuditCallback(param);
    }
}
