package com.chelvc.cloud.vehicle.server.service;

import com.baomidou.mybatisplus.extension.service.IService;
import com.chelvc.cloud.vehicle.client.constant.MerchantStatus;
import com.chelvc.cloud.vehicle.client.dto.MerchantDTO;
import com.chelvc.cloud.vehicle.client.dto.MerchantDetailDTO;
import com.chelvc.cloud.vehicle.client.dto.MerchantRankCountDTO;
import com.chelvc.cloud.vehicle.client.dto.MerchantRankDTO;
import com.chelvc.cloud.vehicle.client.param.*;
import com.chelvc.cloud.vehicle.server.entity.Merchant;
import com.chelvc.framework.common.model.Pagination;

import java.math.BigDecimal;
import java.util.List;
import java.util.Map;

/**
 * 商家业务操作接口
 *
 * @author Woody
 * @date 2023/5/2
 */
public interface MerchantService extends IService<Merchant> {
    /**
     * 获取商家id
     * @param userId 用户id
     * @return
     */
    List<Long> getMerchantIdsByUserId(Long userId);

    /**
     * 商家信息
     * @param merchantId
     * @return
     */
    MerchantDTO getMerchantById(Long merchantId);

    /**
     * 获取商家名称
     */
    String getMerchantName(Long merchantId);


    /**
     * 查询商家排名
     * @param regionId
     * @param limit
     * @param level
     * @return
     */
    List<MerchantRankCountDTO> rankMerchants(Integer regionId, Integer limit, Integer level, Long categoryId);

    /**
     * 根据地区查询上个月所有商家的平台抽成金额
     * @param regionId
     * @param level
     * @return
     */
    BigDecimal queryTotalCommissionAmountByLastMonth(Integer regionId, Integer level, Long categoryId);


    /**
     * 查询用户商家信息
     * @param userId
     * @return
     */
    MerchantDTO getMerchantByUserId(Long userId);


    List<MerchantDTO> getMerchantByIds(List<Long> ids);

    /**
     * 获取附近商家
     *
     * @param param 查询参数
     * @param size  商家数量
     * @return 商家信息列表
     */
    List<MerchantDTO> listNearbyMerchants(LocationQueryParam param, int size);
    /**
     * 分页获取附近商家
     *
     * @param param 查询参数
     * @return 商家信息列表
     */
    Pagination<MerchantDTO> indexMerchantPaging (LocationQueryPagingParam param);

    /**
     * 获取推荐商家
     *
     * @param param 查询参数
     * @param size  商家数量
     * @return 商家信息列表
     */
    List<MerchantDTO> listRecommendMerchants(LocationQueryParam param, int size);

    /**
     * 查询商家
     *
     * @param param 查询参数
     * @return 商家信息列表
     */
    List<MerchantDTO> listSimpleMerchants(MerchantQueryParam param);

    /**
     * 分页查询商家
     *
     * @param param 查询参数
     * @return 商家信息列表
     */
    Pagination<MerchantDTO> merchantPagingList(MerchantQueryParamPaging param);

    /**
     * 获取商家详情
     *
     * @param id 商家ID
     * @return 商家详情
     */
    MerchantDetailDTO getMerchantDetail(Long id);

    /**
     * 获取商家详情
     *
     * @param id 商家ID
     * @param param 查询参数
     * @return 商家详情
     */
    MerchantDetailDTO getMerchantDetail(Long id, LocationQueryParam param);

    /**
     * 新增商家
     *
     * @param param 新增参数
     * @return 商家主键
     */
    Long addMerchant(MerchantModifyParam param);

    /**
     * 修改商家
     *
     * @param id    商家主键
     * @param param 修改参数
     */
    void updateMerchant(Long id, MerchantModifyParam param);

    /**
     * 删除商家
     *
     * @param id    商家主键
     */
    void deleteMerchant(Long id);

    /**
     * 查询商家
     *
     * @param param 查询参数
     * @return 商家分页信息
     */
    Pagination<MerchantDTO> getMerchantPaging(MerchantPagingParam param);

    /**
     * 查询商家信息
     *
     * @param id 商家主键
     * @return 商家信息
     */
    MerchantDTO getMerchant(Long id);

    /**
     * 获取商家信息
     * @return
     */
    List<MerchantDTO> getMerchantIdsByUserId();

    /**
     * 查询商家排名
     * @param param
     * @param userId
     * @return
     */
    List<MerchantRankDTO> listRankMerchants(MerchantRankParam param, Long userId);

    /**
     * 后台查询商家排名
     * @param param
     * @return
     */
    List<MerchantRankDTO> listRankMerchants(MerchantRankParam param);

    /**
     * 我的购物车列表
     * @param param
     * @return
     */
    public Pagination<MerchantDTO> getUserMineCartPaging(OmsCartItemPagingParam param);

    /**
     * 更改商家得营业状态
     * @param merchantId 商家ID
     * @param businessStatus 营业状态
     */
    public void updateMerchantBusinessStatus(Long merchantId,String businessStatus);

    /**
     * 获取商家营业状况
     * @return
     */
    Map<String,Object> operatConditions();

    /**
     * 经营报表
     * @return 经营报表信息
     */
    List<Map<String,Object>> operatReport(ReportModifyParam param);

    /**
     * 商家审核
     * @param id
     * @param status
     */
    void merchantAudit(Long id, MerchantStatus status);


    /**
     * 获取商家入驻统计
     * @return
     */
    List<Map<String,Object>> getMerchantReport(ReportModifyParam param);


    /**
     * 获取商家入驻统计
     * @return
     */
    Map<String,Object> getMerchantReportCount(ReportModifyParam param);

    MerchantDTO queryCheck(Long merchantId, Long userId);

    void merchantApplyNotify(MerchantApplyRecordParam param);

    Merchant queryByApplicant(Long applicant);
}
